==> unify_api-1.0.1.tar.gz: example/lib/ui/marketing.dart <==
import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';

class MarketingExample extends StatelessWidget {
  final UnifyClient client;

  const MarketingExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Marketing'),
        ),
        body: GridView.count(
          crossAxisCount: 2,
          children: <Widget>[
            GridItem(
              iconData: Icons.folder_special,
              name: "Sections",
              details: MarketingSectionListExample(
                client: client,
                name: "Sections",
                sections: client.listMarketingSection(),
              ),
            ),
            GridItem(
              iconData: Icons.description,
              name: "Material",
              details: MarketingMaterialListExample(
                client: client,
                name: "Material",
                material: client.listMarketingMaterial(),
              ),
            ),
            GridItem(
              iconData: Icons.people,
              name: "Campaigns",
              details: MarketingCampaignListExample(
                client: client,
                name: "Campaigns",
                campaigns: client.listMarketingCampaigns(),
              ),
            ),
            GridItem(
              iconData: Icons.people_outline,
              name: "Partners",
              details: MarketingPartnersListExample(
                client: client,
                name: "Partners",
                partners: client.listMarketingPartners(),
              ),
            ),
          ],
        ));
  }
}

class MarketingPartnersListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingPartner>> partners;
  final String name;

  const MarketingPartnersListExample({
    Key key,
    @required this.client,
    @required this.partners,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingPartnersListExampleState createState() =>
      _MarketingPartnersListExampleState();
}

class _MarketingPartnersListExampleState
    extends State<MarketingPartnersListExample> {
  List<MarketingPartner> _items;

  @override
  void initState() {
    widget.partners.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Partners Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.active.toString()),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingCampaignListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingCampaign>> campaigns;
  final String name;

  const MarketingCampaignListExample({
    Key key,
    @required this.client,
    @required this.campaigns,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingCampaignListExampleState createState() =>
      _MarketingCampaignListExampleState();
}

class _MarketingCampaignListExampleState
    extends State<MarketingCampaignListExample> {
  List<MarketingCampaign> _items;

  @override
  void initState() {
    widget.campaigns.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Campaigns Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.status),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingMaterialListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingMaterial>> material;
  final String name;

  const MarketingMaterialListExample({
    Key key,
    @required this.client,
    @required this.material,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingMaterialListExampleState createState() =>
      _MarketingMaterialListExampleState();
}

class _MarketingMaterialListExampleState
    extends State<MarketingMaterialListExample> {
  List<MarketingMaterial> _items;

  @override
  void initState() {
    widget.material.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Material Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.description),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingSectionListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingSection>> sections;
  final String name;

  const MarketingSectionListExample({
    Key key,
    @required this.client,
    @required this.sections,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingSectionListExampleState createState() =>
      _MarketingSectionListExampleState();
}

class _MarketingSectionListExampleState
    extends State<MarketingSectionListExample> {
  List<MarketingSection> _items;

  @override
  void initState() {
    widget.sections.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Sections Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingCategoryListExample(
                                client: widget.client,
                                categories: i.items,
                                name: i.name,
                              )));
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingCategoryListExample extends StatefulWidget {
  final UnifyClient client;
  final List<MarketingCategory> categories;
  final String name;

  const MarketingCategoryListExample({
    Key key,
    @required this.client,
    @required this.categories,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingCategoryListExampleState createState() =>
      _MarketingCategoryListExampleState();
}

class _MarketingCategoryListExampleState
    extends State<MarketingCategoryListExample> {
  List<MarketingCategory> _items;

  @override
  void initState() {
    setState(() {
      _items = widget.categories;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Categories Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: i?.items == null || i.items.isEmpty
                    ? () {
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (BuildContext context) =>
                                    MarketingMaterialListExample(
                                      client: widget.client,
                                      name: i.name,
                                      material: i.listMaterial(),
                                    )));
                      }
                    : () {
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (BuildContext context) =>
                                    MarketingSubCategoryListExample(
                                      client: widget.client,
                                      subcategories: i.items,
                                      name: i.name,
                                    )));
                      },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingSubCategoryListExample extends StatefulWidget {
  final UnifyClient client;
  final List<MarketingSubCategory> subcategories;
  final String name;

  const MarketingSubCategoryListExample({
    Key key,
    @required this.client,
    @required this.subcategories,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingSubCategoryListExampleState createState() =>
      _MarketingSubCategoryListExampleState();
}

class _MarketingSubCategoryListExampleState
    extends State<MarketingSubCategoryListExample> {
  List<MarketingSubCategory> _items;

  @override
  void initState() {
    setState(() {
      _items = widget.subcategories;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty)
            return Center(child: Text("No Sub Categories Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

==> unify_api-1.0.3.tar.gz: example/lib/ui/marketing.dart <==
import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/utils/index.dart';

class MarketingExample extends StatelessWidget {
  final UnifyClient client;

  const MarketingExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Marketing'),
        ),
        body: LayoutBuilder(
          builder: (context, dimens) => GridView.count(
            crossAxisCount: getCrossCount(dimens),
            children: <Widget>[
              GridItem(
                iconData: Icons.folder_special,
                name: "Sections",
                details: MarketingSectionListExample(
                  client: client,
                  name: "Sections",
                  sections: client.listMarketingSection(),
                ),
              ),
              GridItem(
                iconData: Icons.description,
                name: "Material",
                details: MarketingMaterialListExample(
                  client: client,
                  name: "Material",
                  material: client.listMarketingMaterial(),
                ),
              ),
              GridItem(
                iconData: Icons.people,
                name: "Campaigns",
                details: MarketingCampaignListExample(
                  client: client,
                  name: "Campaigns",
                  campaigns: client.listMarketingCampaigns(),
                ),
              ),
              GridItem(
                iconData: Icons.people_outline,
                name: "Partners",
                details: MarketingPartnersListExample(
                  client: client,
                  name: "Partners",
                  partners: client.listMarketingPartners(),
                ),
              ),
            ],
          ),
        ));
  }
}

class MarketingPartnersListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingPartner>> partners;
  final String name;

  const MarketingPartnersListExample({
    Key key,
    @required this.client,
    @required this.partners,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingPartnersListExampleState createState() =>
      _MarketingPartnersListExampleState();
}

class _MarketingPartnersListExampleState
    extends State<MarketingPartnersListExample> {
  List<MarketingPartner> _items;

  @override
  void initState() {
    widget.partners.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Partners Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.active.toString()),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingCampaignListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingCampaign>> campaigns;
  final String name;

  const MarketingCampaignListExample({
    Key key,
    @required this.client,
    @required this.campaigns,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingCampaignListExampleState createState() =>
      _MarketingCampaignListExampleState();
}

class _MarketingCampaignListExampleState
    extends State<MarketingCampaignListExample> {
  List<MarketingCampaign> _items;

  @override
  void initState() {
    widget.campaigns.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Campaigns Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.status),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingMaterialListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingMaterial>> material;
  final String name;

  const MarketingMaterialListExample({
    Key key,
    @required this.client,
    @required this.material,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingMaterialListExampleState createState() =>
      _MarketingMaterialListExampleState();
}

class _MarketingMaterialListExampleState
    extends State<MarketingMaterialListExample> {
  List<MarketingMaterial> _items;

  @override
  void initState() {
    widget.material.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Material Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.description),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingSectionListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<MarketingSection>> sections;
  final String name;

  const MarketingSectionListExample({
    Key key,
    @required this.client,
    @required this.sections,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingSectionListExampleState createState() =>
      _MarketingSectionListExampleState();
}

class _MarketingSectionListExampleState
    extends State<MarketingSectionListExample> {
  List<MarketingSection> _items;

  @override
  void initState() {
    widget.sections.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Sections Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingCategoryListExample(
                                client: widget.client,
                                categories: i.items,
                                name: i.name,
                              )));
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingCategoryListExample extends StatefulWidget {
  final UnifyClient client;
  final List<MarketingCategory> categories;
  final String name;

  const MarketingCategoryListExample({
    Key key,
    @required this.client,
    @required this.categories,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingCategoryListExampleState createState() =>
      _MarketingCategoryListExampleState();
}

class _MarketingCategoryListExampleState
    extends State<MarketingCategoryListExample> {
  List<MarketingCategory> _items;

  @override
  void initState() {
    setState(() {
      _items = widget.categories;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Categories Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: i?.items == null || i.items.isEmpty
                    ? () {
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (BuildContext context) =>
                                    MarketingMaterialListExample(
                                      client: widget.client,
                                      name: i.name,
                                      material: i.listMaterial(),
                                    )));
                      }
                    : () {
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (BuildContext context) =>
                                    MarketingSubCategoryListExample(
                                      client: widget.client,
                                      subcategories: i.items,
                                      name: i.name,
                                    )));
                      },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class MarketingSubCategoryListExample extends StatefulWidget {
  final UnifyClient client;
  final List<MarketingSubCategory> subcategories;
  final String name;

  const MarketingSubCategoryListExample({
    Key key,
    @required this.client,
    @required this.subcategories,
    @required this.name,
  }) : super(key: key);
  @override
  _MarketingSubCategoryListExampleState createState() =>
      _MarketingSubCategoryListExampleState();
}

class _MarketingSubCategoryListExampleState
    extends State<MarketingSubCategoryListExample> {
  List<MarketingSubCategory> _items;

  @override
  void initState() {
    setState(() {
      _items = widget.subcategories;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty)
            return Center(child: Text("No Sub Categories Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.name),
                subtitle: Text(i.count.toString()),
                trailing: JsonButton(json: i?.json),
                onLongPress: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
                onTap: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (BuildContext context) =>
                              MarketingMaterialListExample(
                                client: widget.client,
                                name: i.name,
                                material: i.listMaterial(),
                              )));
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}
